@@ -1,19 +1,17 @@
-from ast import parse
-from beir import util, LoggingHandler
 from beir.datasets.data_loader import GenericDataLoader
 from beir.generation import QueryGenerator as QGen
 from beir.generation.models import QGenModel
-from beir.retrieval.train import TrainRetriever
-from sentence_transformers import SentenceTransformer, losses, models
 import os
 import argparse
 
 
+# TODO: `sep` argument
 def qgen(data_path, output_dir, generator_name_or_path='BeIR/query-gen-msmarco-t5-base-v1', ques_per_passage=3, bsz=32, qgen_prefix='qgen'):
     #### Provide the data_path where nfcorpus has been downloaded and unzipped
     corpus = GenericDataLoader(data_path).load_corpus()
 
     #### question-generation model loading 
+    #### The current version of QGen in BeIR use fixed separation token ' ' !!!
     generator = QGen(model=QGenModel(generator_name_or_path))
 
     #### Query-Generation using Nucleus Sampling (top_k=25, top_p=0.95) ####
